<?php
use Codexpert\Handy_Addons\Helper;

if( !function_exists( 'get_plugin_data' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

if( ! function_exists( 'handy_addons_site_url' ) ) :
function handy_addons_site_url() {
	return get_bloginfo( 'url' );
}
endif;

/**
 * Lists all modules
 *
 * @param bool $details either we need other data along with the module name and slug
 *
 * @return array
 */
if( !function_exists( 'handy_addons_get_modules' ) ) :
function handy_addons_get_modules( $details = false ) {
	$modules = [
		'pdf-invoice'		=> [
			'name'	=> __( 'PDF Invoice', 'handy-addons' ),
			'pro'	=> false,
			'icon'	=> '',
		],
		'product-brands'		=> [
			'name'	=> __( 'Product Brands', 'handy-addons' ),
			'pro'	=> false,
			'icon'	=> '',
		],
		'checkout-editor'	=> [
			'name'	=> __( 'Checkout Editor', 'handy-addons' ),
			'pro'	=> true,
			'icon'	=> '',
		],
		'order-filter'	=> [
			'name'	=> __( 'Order Filter', 'handy-addons' ),
			'pro'	=> false,
			'icon'	=> '',
		],
	];

	if( ! $details ) {
		$_modules = [];
		foreach ( $modules as $key => $module ) {
			$_modules[ $key ] = $module['name'];
		}

		return apply_filters( 'handy_addons-modules', $_modules );
	}

	return apply_filters( 'handy_addons-modules', $modules );
}
endif;

/**
 * Gets a single module data
 *
 * @param string $module the module ID
 *
 * @return array
 */
function handy_addons_get_module( $module ) {
	$modules = handy_addons_get_modules( true );

	return $modules[ $module ];
}

/**
 * Lists active modules
 *
 * @return array
 */
function handy_addons_get_active_modules() {
	$active_modules = Helper::get_option( 'handy_addons_modules', 'enabled', [] );

	return apply_filters( 'handy_addons-active_modules', $active_modules );
}

/**
 * Checks if a given module is enabled
 *
 * @param string $module the module ID
 *
 * @return bool
 */
function handy_addons_module_is_active( $module ) {
	$active_modules = handy_addons_get_active_modules();

	return in_array( $module, $active_modules );
}

/**
 * Checks if an addon for a given module is activated
 *
 * @param string $module the module ID
 *
 * @return bool
 */
function handy_addons_addon_is_active( $module ) {
	return is_plugin_active( "handy-addons-{$module}/handy-addons-{$module}.php" );
}

/**
 * List product categories
 *
 * @since 1.0
 *
 * @return array
 */
if( !function_exists( 'handy_addons_addon_get_terms' ) ) :
function handy_addons_addon_get_terms( $taxonomy = 'product_cat' ) {

	$terms = get_terms( [ 'taxonomy' => $taxonomy, 'hide_empty' => false ] );
	$cats = [];
	if ( is_array( $terms ) ) {		
		foreach ( $terms as $term ) {
			if ( isset( $term->term_id ) ) {
		    	$cats[ $term->term_id ] = $term->name;
			}
		}
	}
	return $cats;
}
endif;

/**
 * Sanitize number input
 * 
 * @param mix $value the value
 * 
 * @uses sanitize_text_field()
 * 
 * @return int The sanitized value
 */
if( ! function_exists( 'codesigner_sanitize_number' ) ) :
function codesigner_sanitize_number( $value, $type = 'int' ){
	if ( $type == 'float' ) {
		return (float) sanitize_text_field( $value );
	}
	else{
		return (int) sanitize_text_field( $value );
	}
}
endif;