<?php
namespace Codexpert\Handy_Addons\Modules\Checkout_Editor;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;
/**
 * All front code 
 * @author Al Imran Akaash <alimranakash.bd@gmail.com>
 */

class Front extends Base{
	public function __construct(){
		$this->id = 'checkout-editor'; 
		$this->action( 'wp_enqueue_scripts', 'enqueue_scripts' );
		$this->filter( 'woocommerce_checkout_fields', 'checkout_fields' );
	}

	public function enqueue_scripts(){
		wp_enqueue_style( $this->id, plugins_url( "modules/{$this->id}/assets/css/front.css", HANDY_ADDONS ) );
		wp_enqueue_script( $this->id, plugins_url( "modules/{$this->id}/assets/js/front.js", HANDY_ADDONS ), [ 'jquery' ] );
		$localized = [
			'ajaxurl'	=> admin_url( 'admin-ajax.php' )
		];
		wp_localize_script( $this->id, 'WCHABUMP', apply_filters( "{$this->id}-localized", $localized ) );
	}

	public function checkout_fields( $wc_fields ) {
		$types 	= Helper::get_option( 'ha_checkout-fields', 'checkout_fields' );

		if ( empty( $types ) ) return $wc_fields;

		$_fields 	= [];

		$_fields['billing'] = $_fields['shipping'] = $_fields['order'] = [];

		foreach ( $types as $type => $fields ) {
			$priority = 10;
			foreach ( $fields as $name => $field ) {
				// if ( isset( $field['enabled'] ) ) {
					$validate = [];
					if( isset(  $wc_fields[ $type ][ $name ]['type'] ) ) {
						$_fields[ $type ][ $name ]['type']		= $wc_fields[ $type ][ $name ]['type'];
					}

					if( isset(  $wc_fields[ $type ][ $name ]['validate'] ) ) {
						$validate = $wc_fields[ $type ][ $name ]['validate'];
					}
					else if( !handy_addons_is_default_field( $name ) ){
						$validate = [ $field['type'] ];
					}

					if ( !handy_addons_is_default_field( $name ) ) {
						$_fields[ $type ][ $name ]['type']		= $field['type'];
					}

					if ( isset( $field['type'] ) && in_array( $field['type'], [ 'select', 'radio' ] ) ) {

						$_options = explode( PHP_EOL, $field['options'] );

						$options = [];
						foreach ( $_options as $_option ) {
							$options[ $_option ] = $_option;
						}

						$_fields[ $type ][ $name ]['options']	= $options;
					}

					$_fields[ $type ][ $name ]['label'] 		= sanitize_text_field( $field['label'] );
					$_fields[ $type ][ $name ]['required'] 		= isset( $field['required'] );

					$_fields[ $type ][ $name ]['priority'] 		= 0;
					$_fields[ $type ][ $name ]['validate'] 		= $validate;
					$_fields[ $type ][ $name ]['placeholder'] 	= isset( $field['placeholder'] ) ? $field['placeholder'] : '';
					$_fields[ $type ][ $name ]['class'][]		= $field['class'];
				// }
				$priority++;
			}
		}

		return $_fields;
	}

	public function view_additional_fields( $order ) {

		if ( is_int( $order ) || is_numeric( $order ) ) {
			$order = wc_get_order( $order );
		}
		
		$custom_fields = handy_addons_get_custom_checkout_fields( $order );
		
		if ( empty( $custom_fields['billing'] ) && empty( $custom_fields['shipping'] ) ) return;

		echo '<section class="ha-additional-fields-details woocommerce-columns woocommerce-columns--2 woocommerce-columns--addresses col2-set addresses">';
		echo '<h2 class="woocommerce-column__title">'. __( 'Additional Fields', 'wc-one-pager' ) .'</h2>';
		$count = 1;
		foreach ( $custom_fields as $key => $custom_field ) {
			if ( !empty( $custom_field ) ) {
				echo "<div class='woocommerce-column woocommerce-column--". esc_attr( $count ) ." woocommerce-column--". esc_attr( $key ) ."-address col-". esc_attr( $count ) ."'>";
				echo '<h4 class="woocommerce-">'. ucwords( esc_html( $key ) ) .'</h4>';
					echo '<address>';

						foreach ( $custom_field as $key => $field ) {
							echo "<p><strong>". esc_html( $key ) .":</strong>". esc_html( $field ) ."</p>";
						}

					echo '</address>';
				echo '</div>';

				$count++;
			}	
		}
		echo '</section>';
	}
}