<?php 
use Codexpert\Handy_Addons\Helper;

$types = Helper::get_option( 'ha_checkout-fields', 'checkout_fields' ) ? : handy_addons_fields();

$shipping_zones = WC_Shipping_Zones::get_zones();

if ( count( $shipping_zones ) <= 0 ) {
	unset( $types['shipping'] );
}

$label_text 		= __( 'Label', 'handy-addons' );
$required_text 		= __( 'Required', 'handy-addons' );
$class_name_text 	= __( 'Class Name', 'handy-addons' );
$id_text 			= __( 'ID', 'handy-addons' );
$type_text 			= __( 'Type', 'handy-addons' );
$option_text		= __( 'Option', 'handy-addons' );
$enable_text		= __( 'Enable', 'handy-addons' );
$remove_text		= __( 'Remove', 'handy-addons' );
$thankyou_text 		= __( 'Show on Thankyou', 'handy-addons' );
$email_text 		= __( 'Show on Email', 'handy-addons' );
$order_text 		= __( 'Show in Order Edit', 'handy-addons' );
$enable_disable_text = __( 'Enable/Disable', 'handy-addons' );

$classes = [ 
	'form-row-first' 	=>  __( 'Row First', 'wc-one-pager' ),
	'form-row-last' 	=>  __( 'Row Last', 'wc-one-pager' ),
	'form-row-wide' 	=>  __( 'Row Wide', 'wc-one-pager' ),
	'notes' 			=>  __( 'Notes', 'wc-one-pager' ),
];

$_field_types = [ 
	'text'			=>	'Text',
	'state'			=>	'State',
	'textarea'		=>	'Textarea',
	'checkbox'		=>	'Checkbox',
	'password'		=>	'Password',
	// 'datetime'		=>	'Datetime',
	// 'datetime-local'=>	'Datetime-local',
	'date'			=>	'Date',
	// 'month'			=>	'Month',
	'time'			=>	'Time',
	// 'week'			=>	'Week',
	'number'		=>	'Number',
	'email'			=>	'Email',
	'url'			=>	'Url',
	'tel'			=>	'Tel',
	'country'		=>	'Country',
	'select'		=>	'Select',
	'radio'			=>	'Radio',
];

$_thankyou_hooks = [
	'woocommerce_before_thankyou' 						=> __( 'Before Thankyou', 'handy-addons' ),
	'woocommerce_order_details_before_order_table' 		=> __( 'Before Order Details', 'handy-addons' ),
	'woocommerce_after_order_details' 					=> __( 'After Order Details', 'handy-addons' ),
	'woocommerce_order_details_after_customer_details' 	=> __( 'After All Details', 'handy-addons' ),
];

$_email_hooks = [
	'woocommerce_email_order_details' 					=> __( 'Order Details', 'handy-addons' ),
	'woocommerce_email_order_meta' 						=> __( 'Order Meta', 'handy-addons' ),
	'woocommerce_email_customer_details' 				=> __( 'Customer Details', 'handy-addons' ),
];

$_order_hooks = [
	'woocommerce_admin_order_data_after_order_details' 		=> __( 'After Order Details', 'handy-addons' ),
	'woocommerce_admin_order_data_after_billing_address' 	=> __( 'After Billing Details', 'handy-addons' ),
	'woocommerce_admin_order_data_after_shipping_address' 	=> __( 'After Shipping Details', 'handy-addons' ),
	'woocommerce_admin_order_items_after_shipping' 			=> __( 'Order Items After Shipping', 'handy-addons' ),
	'woocommerce_admin_order_totals_after_tax' 				=> __( 'After Tax', 'handy-addons' ),
	'woocommerce_admin_order_totals_after_total' 			=> __( 'After Order Total', 'handy-addons' ),
	'woocommerce_order_item_add_action_buttons' 			=> __( 'After Action Buttons', 'handy-addons' ),
];
?>

<div id="ha-checkout-panel">
	<?php 

	$get_type_args = [];
	foreach ( $types as $type => $fields ): 
		$get_type_args[] = $type;
		?>
		
		<div class="ha-checkout-columns ha-checkout-<?php echo esc_attr( $type ); ?>">
			<h4><span><?php echo ucwords( esc_html( $type ) ) ?></span></h4>

			<ul id="ha-<?php esc_attr_e( $type ) ?>-sortable" class="ha-sortable">
				<?php 

				foreach ( $fields as $name => $field ) :


					$disabled 		= '';
					$readonly 		= '';
					$hide 			= '';

					if ( handy_addons_is_default_field( $name ) ) {
						$disabled 	= 'disabled';
						$readonly 	= 'readonly';
						$hide 		= 'ha-hide';
					}

					if ( isset( $field['enabled'] ) && $field['enabled'] == true ) {
						$enabled 	= 'checked';
					}
					else{
						$enabled 	= '';
					}

					if ( isset( $field['required'] ) && $field['required'] == true ) {
						$required 	= 'checked';
					}
					else{
						$required 	= '';
					}

					$class_options = '';
					foreach ( $classes as $value => $class ) {
						$class_options .= "<option value=". esc_attr( $value ) ." ". selected( $value, $field['class'], false ) .">". esc_html( $class ) ."</option>";
					}

					$set_type = isset( $field['type'] ) ? $field['type'] : '';
					$field_types = '';
					foreach ( $_field_types as $value => $field_type ) {
						$field_types .= "<option value=". esc_attr( $value ) ." ". selected( $value, $set_type, false ) .">". esc_html( $field_type ) ."</option>";
					}

					$set_thankyou_hooks = isset( $field['thankyou_hooks'] ) ? $field['thankyou_hooks'] : '';
					$thankyou_hooks = '<option value="dont">'. __( 'Dont\'t Show', 'handy-addons' ) .'</option>';
					foreach ( $_thankyou_hooks as $value => $field_type ) {
						$thankyou_hooks .= "<option value=". esc_attr( $value ) ." ". selected( $value, $set_thankyou_hooks, false ) .">". esc_html( $field_type ) ."</option>";
					}

					$set_email_hooks = isset( $field['email_hooks'] ) ? $field['email_hooks'] : '';
					$email_hooks = '<option value="">'. __( 'Dont\'t Show', 'handy-addons' ) .'</option>';
					foreach ( $_email_hooks as $value => $field_type ) {
						$email_hooks .= "<option value=". esc_attr( $value ) ." ". selected( $value, $set_email_hooks, false ) .">". esc_html( $field_type ) ."</option>";
					}

					$set_order_hooks = isset( $field['order_hooks'] ) ? $field['order_hooks'] : '';
					$order_hooks = '<option value="">'. __( 'Dont\'t Show', 'handy-addons' ) .'</option>';
					foreach ( $_order_hooks as $value => $field_type ) {
						$order_hooks .= "<option value=". esc_attr( $value ) ." ". selected( $value, $set_order_hooks, false ) .">". esc_html( $field_type ) ."</option>";
					}

					$show = '';
					if ( $set_type == 'select' || $set_type == 'radio' ) {
						$show 		= 'ha-show';
					}

					$set_options 	= isset( $field['options'] ) ? $field['options'] : '';
					$label 			= sanitize_text_field( $field['label'] );
					$id 			= sanitize_text_field( $field['id'] );

					echo "<li class='ha-single-field'>";
					echo "<div class='ha-accordion'>";
					echo "<p class='ha-heading' data-name=". esc_attr( $name ) ."><span class='dashicons dashicons-menu-alt2'></span><span class='ha-heading-text'> ". esc_html( $label ) ."</span></p>";
						echo "
						<div class='ha-checkout-input-area ". esc_attr( $name ) ." {$hide} {$show}'>
							<p class='ha-field-label'>
								<label class='ha-block' for=''>". esc_html( $label_text ) ."</label>
								<input class='ha-input-label' type='text' name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][label]' value='". esc_attr( $label ) ."'>
							</p>

							<p class='ha-field-type'>
								<label class='ha-block' for=''>". esc_html( $type_text ) ."</label>
								<select name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][type]'>{$field_types}</select>
							</p>

							<p class='ha-field-options'>
								<label class='ha-block' for=''>". esc_html( $option_text ) ."</label>
								<textarea class='ha-input-options' name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][options]' rows='4'>{$set_options}</textarea>
							</p>

							<p class='ha-field-id'>
								<label class='ha-block' for=''>". esc_html( $id_text ) ."</label>
								<input class='ha-input-id' data-oldid='". esc_attr( $id ) ."' type='text' name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][id]' value='". esc_attr( $id ) ."' {$readonly}>
							</p>
							
							<p class='ha-field-required'>
								<label for='". esc_attr( $name ) ."'>". esc_html( $required_text ) ."</label>
								<input id='". esc_attr( $name ) ."' type='checkbox' name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][required]' {$required}>
							</p>

							<p class='ha-field-class'>
								<label class='ha-block' for=''>". esc_html( $class_name_text ) ."</label>
								<select name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][class]'>{$class_options}</select>
							</p>";

							if ( !handy_addons_is_default_field( $name ) ) {
								echo "<p class='ha-field-thankyou-hooks'>
									<label class='ha-block' for=''>". esc_html( $thankyou_text ) ."</label>
									<select name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][thankyou_hooks]'>{$thankyou_hooks}</select>
								</p>

								<p class='ha-field-email-hooks'>
									<label class='ha-block' for=''>". esc_html( $email_text ) ."</label>
									<select name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][email_hooks]'>{$email_hooks}</select>
								</p>

								<p class='ha-field-order-review-hooks'>
									<label class='ha-block' for=''>". esc_html( $order_text ) ."</label>
									<select name='checkout_fields[". esc_attr( $type ) ."][". esc_attr( $name ) ."][order_hooks]'>{$order_hooks}</select>
								</p>";
							}

						echo "</div>";
					echo "</div>";
					echo "
					<div class='handy_addons-field-action'>
						<button class='ha-field-remove' data-type=". esc_attr( $type ) .">-</button>
						<button class='ha-clone-field' data-type=". esc_attr( $type ) .">+</button>
					</div>";
					echo "</li>";
				endforeach;
				?>
			</ul>

			<div id="ha-clone-<?php echo esc_attr( $type ); ?>-field" class="ha-clone-field-area">
				<li class="ha-single-field">
					<div class="ha-accordion">
						<p class="ha-heading" data-%name%="<?php echo esc_attr( $type ); ?>_%%%">
							<span class="dashicons dashicons-menu-alt2"></span> <span class="ha-heading-text"><?php _e( 'New Field', 'handy-addons' ); ?></span>
						</p>
						<div class="ha-checkout-input-area <?php echo esc_attr( $type ); ?>_%%%" style="display: none;">
							<p class='ha-field-label'>
								<label class="ha-block" for=""><?php _e( 'Label', 'handy-addons' ); ?></label>
								<input class="ha-input-label" type="text" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][label]" value="<?php _e( 'New Field', 'handy-addons' ); ?>">
							</p>

							<p class='ha-field-type'>
								<label class="ha-block" for=""><?php _e( 'Type', 'handy-addons' ); ?></label>
								<select %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][type]">
									<?php echo $field_types; ?>
								</select>
							</p>

							<p class='ha-field-options'>
								<label class="ha-block" for=""><?php _e( 'Options', 'handy-addons' ); ?></label>
								<textarea class="ha-input-options" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][options]" rows="4">
Option 1
Option 2
Option 3</textarea>
							</p>

							<p class='ha-field-id'>
								<label class="ha-block" for=""><?php _e( 'Id', 'handy-addons' ); ?></label>
								<input class="ha-input-id" type="text" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][id]" value="<?php _e( 'new_field', 'handy-addons' ); ?>">
							</p>
							
							<p class='ha-field-required'>
								<input id="<?php echo esc_attr( $type ); ?>_%%%" type="checkbox" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][required]">
								<label for="<?php echo esc_attr( $type ); ?>_%%%"><?php _e( 'Required', 'handy-addons' ); ?></label>
							</p>

							<p class='ha-field-class'>
								<label class="ha-block" for=""><?php _e( 'Class Name', 'handy-addons' ); ?></label>
								<select %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][class]">
									<?php echo $class_options; ?>
								</select>
							</p>

							<p class='ha-field-thankyou-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $thankyou_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ) ?>][<?php echo esc_attr( $type ); ?>_%%%][thankyou_hooks]'>
									<?php echo $thankyou_hooks; ?>
								</select>
							</p>

							<p class='ha-field-email-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $email_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ) ?>][<?php echo esc_attr( $type ); ?>_%%%][email_hooks]'>
									<?php echo $email_hooks; ?>
								</select>
							</p>

							<p class='ha-field-order-review-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $order_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ) ?>][<?php echo esc_attr( $type ); ?>_%%%][order_hooks]'>
									<?php echo $order_hooks; ?>
								</select>
							</p>
						</div>
					</div>
					<div class="handy_addons-field-action">
						<button class="ha-field-remove" data-type="<?php echo esc_attr( $type ); ?>">-</button>
						<button class="ha-clone-field" data-type="<?php echo esc_attr( $type ); ?>">+</button>
					</div>
				</li>
			</div>
		</div>
	<?php endforeach;

	$check_types = [ 'billing', 'shipping', 'order' ];
	foreach ( $check_types as $check_type ) {
		if ( !in_array( $check_type, $get_type_args ) ) {

			echo '<div class="ha-checkout-columns ha-checkout-'. esc_attr( $check_type ) .'">
			<h4><span>'. ucwords( esc_html( $check_type ) ) .'</span></h4>

			<ul id="ha-'. esc_attr( $check_type ) .'-sortable" class="ha-sortable">';

			echo '<li><div class="handy_addons-field-action handy_addons-new-action-'. esc_attr( $check_type ) .'">
				<button class="ha-clone-field" data-type="'. esc_attr( $check_type ) .'">+</button>
			</div></li>';

			echo '</ul></div>';

			$type = $check_type;

			?>
			<div id="ha-clone-<?php echo esc_attr( $type ); ?>-field" class="ha-clone-field-area">
				<li class="ha-single-field">
					<div class="ha-accordion">
						<p class="ha-heading" data-%name%="<?php echo esc_attr( $type ); ?>_%%%">
							<span class="dashicons dashicons-menu-alt2"></span> <span class="ha-heading-text"><?php _e( 'New Field', 'handy-addons' ); ?></span>
						</p>

						<div class="ha-checkout-input-area <?php echo esc_attr( $type ); ?>_%%%" style="display: none;">
							<p class='ha-field-label'>
								<label class="ha-block" for=""><?php _e( 'Label', 'handy-addons' ); ?></label>
								<input class="ha-input-label" type="text" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][label]" value="<?php _e( 'New Field', 'handy-addons' ); ?>">
							</p>

							<p class='ha-field-type'>
								<label class="ha-block" for=""><?php _e( 'Type', 'handy-addons' ); ?></label>
								<select %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][type]">
									<?php echo $field_types; ?>
								</select>
							</p>

							<p class='ha-field-options'>
								<label class="ha-block" for=""><?php _e( 'Options', 'handy-addons' ); ?></label>
								<textarea class="ha-input-options" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][options]" rows="4">
Option 1
Option 2
Option 3</textarea>
							</p>

							<p class='ha-field-id'>
								<label class="ha-block" for=""><?php _e( 'Id', 'handy-addons' ); ?></label>
								<input class="ha-input-id" type="text" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][id]" value="<?php _e( 'new_field', 'handy-addons' ); ?>">
							</p>
							
							<p class='ha-field-required'>
								<input id="<?php echo esc_attr( $type ); ?>_%%%" type="checkbox" %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][required]">
								<label for="<?php echo esc_attr( $type ); ?>_%%%"><?php _e( 'Required', 'handy-addons' ); ?></label>
							</p>

							<p class='ha-field-class'>
								<label class="ha-block" for=""><?php _e( 'Class Name', 'handy-addons' ); ?></label>
								<select %name%="checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][class]">
									<?php echo $class_options; ?>
								</select>
							</p>

							<p class='ha-field-thankyou-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $thankyou_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][thankyou_hooks]'>
									<?php echo $thankyou_hooks; ?>
								</select>
							</p>

							<p class='ha-field-email-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $email_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][email_hooks]'>
									<?php echo $email_hooks; ?>
								</select>
							</p>

							<p class='ha-field-order-review-hooks'>
								<label class='ha-block' for=''><?php echo esc_html( $order_text ); ?></label>
								<select %name%='checkout_fields[<?php echo esc_attr( $type ); ?>][<?php echo esc_attr( $type ); ?>_%%%][order_hooks]'>
									<?php echo $order_hooks; ?>
								</select>
							</p>
						</div>
					</div>
					<div class="handy_addons-field-action">
						<button class="ha-field-remove" data-type="<?php echo esc_attr( $type ); ?>">-</button>
						<button class="ha-clone-field" data-type="<?php echo esc_attr( $type ); ?>">+</button>
					</div>
				</li>
			</div>
			<?php
		}
	}
	?>

</div>
