<?php
namespace Codexpert\Handy_Addons\Modules;
use Codexpert\Handy_Addons\Helper;
use Codexpert\Plugin\Base;

/**
 * if accessed directly, exit.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Order Filter
 *
 * Adds more filter options to the order screen
 *
 * @package Modules
 * @subpackage Order_Filter
 * @author codexpert <hi@codexpert.io>
 */
class Order_Filter extends Base {

	public $id;

	public $module;
	
	public static $_instance;

	/**
	 * Constructor function
	 */
	public function __construct() {

		$this->id = basename( __FILE__, '.php' );

		// if we have an addon activated for this module, don't proceed
		if( handy_addons_addon_is_active( $this->id ) ) return;

		// get the module data
		$this->module =  handy_addons_get_module( $this->id );

		$this->module['name'] = "{$this->module['icon']} {$this->module['name']}";

		// execute the hooks
		$this->hook();
	}

	public function hook() {
		$this->action( 'admin_enqueue_scripts', 'enqueue_scripts' );
		$this->action( 'plugins_loaded', 'add_menu', 11 );
		$this->action( 'restrict_manage_posts', 'add_order_filter_menu', 99 );
		$this->filter( 'request', 'filter_orders', 99 );
		$this->action( 'admin_footer', 'overlay' );
		$this->priv( 'handy-addons-get-products', 'get_products' );
	}

	public function enqueue_scripts() {

		wp_enqueue_style( $this->id . '-chosen', plugins_url( "modules/{$this->id}/assets/css/chosen.css", HANDY_ADDONS ) );
		wp_enqueue_style( $this->id . '-select2', plugins_url( "modules/{$this->id}/assets/css/select2.min.css", HANDY_ADDONS ) );
		wp_enqueue_style( $this->id, plugins_url( "modules/{$this->id}/assets/css/style.css", HANDY_ADDONS ) );

		wp_enqueue_script( 'jquery-ui-datepicker' );
		wp_enqueue_script( $this->id . '-chosen', plugins_url( "modules/{$this->id}/assets/js/chosen.jquery.min.js", HANDY_ADDONS ), [ 'jquery' ] );
		wp_enqueue_script( $this->id . '-select2', plugins_url( "modules/{$this->id}/assets/js/select2.min.js", HANDY_ADDONS ), [ 'jquery' ] );
		wp_enqueue_script( $this->id, plugins_url( "modules/{$this->id}/assets/js/script.js", HANDY_ADDONS ), [ 'jquery' ] );
	}

	public function add_menu() {
		
		$date_format = get_option( 'date_format' );
		$settings = [
			'id'            => $this->id,
			'label'         => $this->module['name'],
			'title'         => __( 'Order Filter', 'handy-addons' ),
			'header'        => __( 'Order Filter', 'handy-addons' ),
			'priority'		=> 10,
			'capability'	=> 'manage_options',
			'parent'		=> 'handy-addons',
			'icon'			=> 'dashicons-yes',
			'position'		=> 56,
			'sections'      => [
				'order-filter-general'	=> [
					'id'        => 'order-filter-general',
					'label'     => __( 'General', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					'sticky'	=> true,
					'page_load'	=> true,
					'fields'    => [
						'enabled' => [
							'id'        => 'enabled',
							'label'     => __( 'Enable', 'handy-addons' ),
							'type'      => 'switch',
							'multiple'	=> true,
							'options'	=> $this->filter_inputs(),
							'default'	=> ['categories', 'product_ids', 'order_date'],
							'desc'      => __( 'Enable fields that want to use for filtering order.', 'handy-addons' ),
						],
					]
				],
			],
		];

		new \Codexpert\Plugin\Settings( $settings );
	}

	private function filter_inputs(){
		
		$inputs = [
			'categories' 	=> __( 'Categories', 'handy-addons' ),
			'product_types' => __( 'Product Types', 'handy-addons' ),
			'product_ids' 	=> __( 'Products', 'handy-addons' ),
			'product_atts' 	=> __( 'Product Attributes', 'handy-addons' ),
			'order_date' 	=> __( 'Order Date', 'handy-addons' ),
		];

		return $inputs;
	}

	public function callback_menu() {
		echo "
		<div class='wrap'>
			<h2> ". esc_html( $this->module['name'] ) ." </h2>
		</div>";
	}

	public function get_products() {
		$response = [];

		$args = [ 'post_type' => 'product' ];

		if ( $_POST['category'] != '' ) {			
			$args['tax_query'][] = [
				'taxonomy' => 'product_cat',  //taxonomy name  here, I used 'product_cat'
				'field' => 'id',
				'terms' => sanitize_text_field( $_POST['category'] )
			];
		}

		if ( $_POST['type'] != '' ) {			
			$args['tax_query'][] = [
				'taxonomy' => 'product_type',  //taxonomy name  here, I used 'product_cat'
				'field' => 'slug',
				'terms' => sanitize_text_field( $_POST['type'] )
			];
		}

		$args['tax_query']['relation'] = 'AND';

		$products = Helper::get_posts( $args );

		if( count( $products ) <= 0 ) {
			wp_send_json( [ 'status' => 0 ] );
		}
		$html = '';
		foreach ( $products as $product_id => $product_title ) {
			if ( \WC_Product_Factory::get_product_type( $product_id ) == 'variable' ) {
				$product 		= wc_get_product($product_id);
				$children_ids 	= $product->get_children();
				$optgroup 		= '';
				foreach( $children_ids as $child_id ){
					$title 	  = get_the_title( $child_id );
					$optgroup.= "<option value='{$child_id}'>{$title}</option>";
				}
				$html .= "<optgroup label='{$product_title}'>{$optgroup}</optgroup>"; 
			}else{
				$html .= "<option value='{$product_id}'>{$product_title}</option>";
			}
		}

		wp_send_json( [ 'status' => 1, 'html' => $html ] );
	}

	/**
	 * add search input fields to admin order list 
	 *
	 * @author Jakaria Istauk <jakariamd35@gmail.com>
	 * 
	 * @since 1.0
	 */
	public function add_order_filter_menu() {
		global $typenow;

		if ( 'shop_order' != $typenow ) return;

		// echo "modules/{$this->id}/views";

		echo Helper::get_template( 'filter-inputs', "modules/{$this->id}/views" );
	}


	/**
	 * Get All orders IDs for a given product ID.
	 *
	 * @param  integer  $product_id (required)
	 * @param  string  $key _product_id|_variation_id
	 * @param  bool  $exclusive get order that contains ONLY this product
	 *
	 * @link https://stackoverflow.com/a/45849573/3747157
	 *
	 * @return array
	 */
	public function get_orders_of( $product_ids, $key = '_product_id', $exclusive = true ) {
	    global $wpdb;

	    if( count( $product_ids ) < 1 ) return [];

	    $product_ids = implode( ',', $product_ids );

	    $results = $wpdb->get_col("
	        SELECT order_items.order_id
	        FROM {$wpdb->prefix}woocommerce_order_items as order_items
	        LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
	        LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
	        WHERE posts.post_type = 'shop_order'
	        AND order_items.order_item_type = 'line_item'
	        AND order_item_meta.meta_key = '{$key}'
	        AND order_item_meta.meta_value IN ( $product_ids )
	    ");

	    if( ! $exclusive ) {
	    	return $results;
	    }

	    $order_ids = [];
	    foreach ( $results as $order_id ) {
	    	$order = wc_get_order( $order_id );

	    	$item_count = count( $order->get_items() );
	    	if( $item_count > 0 ) {
	    		$order_ids[] = $order_id;
	    	}
	    }
	    return $order_ids;
	}

	/**
	 * formate inputs for post query 
	 *
	 * @author Jakaria Istauk <jakariamd35@gmail.com>
	 * 
	 * @since 1.0
	 */
	public function filter_orders( $vars ) {
		global $typenow;

		if ( 'shop_order' != $typenow ) return $vars;

		$item_id 	= $variation_id = [];
		$is_filter 	= false;

		if ( isset( $_GET['product_id'] ) && count( $_GET['product_id'] ) > 0 ) {
			foreach( $_GET['product_id'] as $product_id ){
				$product_id = (int)sanitize_text_field( $product_id );
				$type 		= \WC_Product_Factory::get_product_type( $product_id );

				if ( 'variation' == $type ) {
					$variation_id[] = $product_id;
				}else{
					$item_id[] = $product_id;
				}
			}
			$is_filter 	= true;
		}

		/**
		 * Get Product ids by category and types  
		 */
		elseif ( isset( $_GET['product_category'] ) || isset( $_GET['p_type'] ) ) {

			$args = [ 'post_type' => 'product' ];
			$tax_query = [];
			$has_variable = false;
			if ( '' != $_GET['product_category'] ) {
				$tax_query[] = [
					'taxonomy' 	=> 'product_cat',  //taxonomy name  here, I used 'product_cat'
					'field' 	=> 'id',
					'terms' 	=> sanitize_text_field( $_GET['product_category'] )
				];
			}
			if ( '' != $_GET['p_type'] ) {
				$tax_query[] = [
					'taxonomy' 	=> 'product_type',  //taxonomy name  here, I used 'product_cat'
					'field' 	=> 'slug',
					'terms' 	=> sanitize_text_field( $_GET['p_type'] )
				];
				$has_variable = true;
			}					


			if ( count( $tax_query ) > 0 ) {
				$args['tax_query'][] = $tax_query;
				$args['tax_query']['relation'] = 'AND';
				$products = Helper::get_posts( $args , false );

				if ( count( $products ) > 0 && $has_variable ) {
					foreach ( $products as $product_id => $product_title ) {
						if ( \WC_Product_Factory::get_product_type( $product_id ) == 'variable' ) {
							$product 		= wc_get_product( $product_id );
							$children_ids 	= $product->get_children();
							$variation_id += $children_ids;
						}
					}
				}

				$item_id  = array_keys($products);
				$is_filter = true;
			}
		}
		

		/**
		 * Get Product ids by attributes  
		 */
		if ( isset( $_GET['product_attribute'] ) && count( $_GET['product_attribute'] ) > 0 ) {
			$attributes = sanitize_text_field( $_GET['product_attribute'] );
			$tax_query 	= [];
			foreach( $attributes as $attribute ){
				if ( isset( $_GET[ $attribute ] ) && count( $_GET[ $attribute ] ) > 0 ) {
					$tax_query[] = [
						'taxonomy' => 'pa_'.sanitize_text_field( $attribute ),  //taxonomy name  here, I used 'product_cat'
						'field' => 'slug',
						'terms' => sanitize_text_field( $_GET[ $attribute ] ),
						'operator' => 'IN'
					];
				}
			}
			if ( count( $tax_query ) > 0 ){				
				$tax_query['relation'] = 'AND';
				$args = [
					'post_type' => 'product',
					'tax_query' => $tax_query,
				];

				$products = Helper::get_posts( $args , false );
				$_item_id = array_keys($products);
				if ( count( $products ) > 0 ) {
					$item_id = array_merge( $_item_id, $item_id );
					$item_id = array_unique( $item_id );
					$is_filter = true;
				}
			}
		}

		/**
		 * Get order ids by product ids and pushed in query  
		 */
		if( $is_filter ){
			$orders = [];

			if ( count( $item_id ) > 0 ) {
				$orders = $this->get_orders_of( $item_id, '_product_id' ); //get order for product id
			}

			if ( count( $variation_id ) > 0 ) {
				$orders_v = $this->get_orders_of( $variation_id, '_variation_id' ); // get order for variation id
				$orders = array_merge( $orders, $orders_v );
			}

			$post__in 	= count( $orders ) <= 0 ? [ 0 ] : $orders;
			$vars[ 'post__in' ] = array_unique( $post__in );
		}

		/**
		 * Date values pushed in query  
		 */
		if ( isset( $_GET['date_type'] ) ){
			$time_start = " 00:00:00";
			$time_end 	= " 23:59:59";
			$date_format= "Y-m-d";
			$today 		= strtotime( 'today' );
			$yesterday 	= strtotime( 'yesterday' );
			$tomorrow 	= strtotime( 'tomorrow' );
			$date_query = false;
			$from = $to = date( $date_format );

			if ( $_GET['date_type'] == 'today' ) {
				$from 	= date( $date_format) . $time_start;
				$to 	= date( $date_format) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == 'yesterday' ) {
				$from 	= date( $date_format, $yesterday) . $time_start;
				$to 	= date( $date_format, $yesterday) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == '7days' ) {
				$from 	= date( $date_format, $today - WEEK_IN_SECONDS ) . $time_start;
				$to 	= date( $date_format, $today ) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == '30days' ) {
				$from 	= date( $date_format, $today - MONTH_IN_SECONDS ) . $time_start;
				$to 	= date( $date_format, $today ) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == 'thismonth' ) {
				$from 	= date( $date_format, $tomorrow - date('d') * DAY_IN_SECONDS ) . $time_start;
				$to 	= date( $date_format, $today ) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == 'lastmonth' ) {
				$from 	= date( $date_format, strtotime("first day of previous month") ) . $time_start;
				$to 	= date( $date_format, strtotime("last day of previous month") ) . $time_end;
				$date_query = true;
			}
			elseif ( $_GET['date_type'] == 'custom' ) {
				$from 	= sanitize_text_field( $_GET['from'] ) . $time_start;
				$to 	= sanitize_text_field( $_GET['to'] ) . $time_end;
				$date_query = true;
			}

			if ( $date_query ) {
			    $vars['date_query']	= [
				    	'after' 	=> $from,
				    	'before' 	=> $to,
				        'inclusive' => true
			    ];
			}
		}

		return $vars;
	}

	public function overlay() {
		echo "
		<div id='order-filter-overlay' style='display:none'>
			<div class='lds-spinner'><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>
		</div>";
	}

	/**
	 * Instantiate the module
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
}

Order_Filter::instance();