<?php
use Codexpert\Handy_Addons\Helper;

$args = [ 'post_type' => 'product' ];

if ( isset( $_GET['product_category'] ) && $_GET['product_category'] != '' ) {			
	$args['tax_query'][] = [
		'taxonomy' 	=> 'product_cat',  //taxonomy name  here, I used 'product_cat'
		'field' 	=> 'id',
		'terms' 	=> sanitize_text_field( $_GET['product_category'] )
	];
}

if ( isset( $_GET['p_type'] ) && $_GET['p_type'] != '' ) {			
	$args['tax_query'][] = [
		'taxonomy' 	=> 'product_type',  //taxonomy name  here, I used 'product_cat'
		'field' 	=> 'slug',
		'terms' 	=> sanitize_text_field( $_GET['p_type'] )
	];
}

$args['tax_query']['relation'] = 'AND';
$products 	= Helper::get_posts( $args );

$variations	= isset( $_GET['product_id'] ) && $_GET['product_id'] != '' ? Helper::get_posts( [ 'post_type' => 'product_variation', 'post_parent' => sanitize_text_field( $_GET['product_id'] ) ] ) : [];
$_variations_disabled	= count( $variations ) > 0 ? '' : 'disabled';
$_show_variations		= count( $variations ) > 0 ? 'block' : 'none';

$from		= isset( $_GET['from'] ) && $_GET['from'] != '' ? sanitize_text_field( $_GET['from'] ) : date( 'Y-m-d', current_time( 'timestamp' ) - WEEK_IN_SECONDS );
$to			= isset( $_GET['to'] ) && $_GET['to'] != '' ? sanitize_text_field( $_GET['to'] ) : date( 'Y-m-d', current_time( 'timestamp' ) );

$date_type 		= isset( $_GET['date_type'] ) ? sanitize_text_field( $_GET['date_type'] ) : '';
$categories 	= get_terms( 'product_cat' );
$attributes 	= wc_get_attribute_taxonomies();
$product_types 	= wc_get_product_types();
$settings 		= Helper::get_option( 'order-filter-general', 'enabled', [] );

if ( in_array( 'categories', $settings ) ): ?>
<select id='of-product_category' name='product_category'>
	<?php
	echo "<option value=''>" . __( 'All Categories', 'handy-addons' ) . "</option>";
	$_category_id = isset( $_GET['product_category'] ) ? sanitize_text_field( $_GET['product_category'] ) : '';
	
	foreach ( $categories as $category ) {
		echo "<option value='". esc_attr( $category->term_id ) ."' " . selected( $_category_id, $category->term_id, false ) . ">". esc_html( $category->name ) ."</option>";
	}
	?>
</select>
<?php endif;

if ( in_array( 'product_types', $settings ) ): ?>
<select id='of-product_type' name='p_type'>
	<?php
	echo "<option value=''>" . __( 'All Product Types', 'handy-addons' ) . "</option>";
	$_type = isset( $_GET['p_type'] ) ? sanitize_text_field ( $_GET['p_type'] ) : '';
	foreach ( $product_types as $type => $label ) {
		echo "<option value='".esc_attr( $type )."' " . selected( $_type, $type, false ) . ">". esc_html( $label ) ."</option>";
	}
	?>
</select>
<?php endif;

if ( in_array( 'product_ids', $settings ) ): ?>
<select name='product_id[]' id='of-product_id' class="of-chosen of-select2" multiple="true" height='30'>
	<?php
	foreach ( $products as $product_id => $product_title ) {
		if ( \WC_Product_Factory::get_product_type( $product_id ) == 'variable' ) {
			$product 		= wc_get_product( $product_id );
			$children_ids 	= $product->get_children();
			$optgroup 		= '';

			echo "<optgroup label='" . esc_attr( $product_title ) . "'>";
			foreach( $children_ids as $child_id ){
				$title 	  = get_the_title( $child_id );
				$selected = isset( $_GET['product_id'] ) && in_array( $child_id, $_GET['product_id'] ) ? "selected='selected'" : '';
				echo "<option value='" . esc_attr( $child_id ) . "' {$selected}>" . esc_html( $title ) . "</option>";
			}
			echo "</optgroup>"; 
		}
		else {
			$selected = isset( $_GET['product_id'] ) && in_array( $product_id, $_GET['product_id'] ) ? "selected='selected'" : '';
			echo "<option value='" . esc_attr( $product_id ) . "' {$selected}>" . esc_html( $product_title ) . "</option>";
		}
	}
	?>	
</select>
<select id='_of_hidden_product_ids'>
	<?php
	foreach ( $products as $product_id => $product_title ) {
		if ( \WC_Product_Factory::get_product_type( $product_id ) == 'variable' ) {
			$product 		= wc_get_product($product_id);
			$children_ids 	= $product->get_children();
			$option_group 	= '';

			echo "<optgroup label='" . esc_attr( $product_title ) . "'>";
			foreach( $children_ids as $child_id ){
				$title 	  = get_the_title( $child_id );
				$selected = isset( $_GET['product_id'] ) && in_array( $child_id, $_GET['product_id'] ) ? "selected='selected'" : '';
				echo "<option value='" . esc_attr( $child_id ) . "' {$selected}>" . esc_html( $title ) . "</option>";
			}
			echo "</optgroup>"; 
		}
		else {
			$selected = isset( $_GET['product_id'] ) && in_array( $product_id, $_GET['product_id'] ) ? "selected='selected'" : '';
			echo "<option value='" . esc_attr( $product_id ) . "' {$selected}>" . esc_html( $product_title ) . "</option>";
		}
	}
	?>
</select>
<?php endif;

if ( count( $attributes ) > 0 && in_array( 'product_atts', $settings ) ): ?>
	<select id="of-product-attributes" class="of-chosen of-select2" name="product_attribute[]" multiple="true">
		<?php
			foreach ( $attributes as $attribute ) {
				$selected = isset( $_GET['product_attribute'] ) && in_array( $attribute->attribute_name, $_GET['product_attribute'] ) ? "selected='selected'" : '';
				echo "<option value='" . esc_attr( $attribute->attribute_name ) . "' {$selected}>" . esc_html( $attribute->attribute_label ) . "</option>";
			}
		 ?>
	</select>
	<?php 
	foreach ( $attributes as $attribute ): 
			$attr_terms = get_terms( "pa_{$attribute->attribute_name}" );
			$options 	= '';
			foreach( $attr_terms as $term ){
				$selected = isset( $_GET[ $attribute->attribute_name ] ) && in_array( $term->slug, $_GET[ $attribute->attribute_name ] ) ? "selected='selected'" : '';
				$options .= "<option value='". esc_attr( $term->slug ) ."' {$selected}>". esc_html( $term->name ) ."</option>";
			}
			echo "<select id='of-product-term-". esc_attr( $attribute->attribute_name ) ."' class='of-product-term of-select2' name='". esc_attr( $attribute->attribute_name ) ."[]' multiple='true' placeholder='Select ". esc_attr( $attribute->attribute_name ) ."'> {$options}</select>";
	endforeach;
endif;

if ( in_array( 'order_date', $settings ) ): ?>
<select id="of-date_type" name="date_type">
	<option value="" ><?php _e( 'All Dates', 'handy-addons' ) ?></option>
	<option value="today" <?php selected( 'today', $date_type ) ?>><?php _e( 'Today', 'handy-addons' ); ?></option>
	<option value="yesterday" <?php selected( 'yesterday', $date_type ) ?>><?php _e( 'Yesterday', 'handy-addons' ); ?></option>
	<option value="7days" <?php selected( '7days', $date_type ) ?>><?php _e( 'Last 7 Days', 'handy-addons' ); ?></option>
	<option value="30days" <?php selected( '30days', $date_type ) ?>><?php _e( 'Last 30 Days', 'handy-addons' ); ?></option>
	<option value="thismonth" <?php selected( 'thismonth', $date_type ) ?>><?php _e( 'This Month', 'handy-addons' ); ?></option>
	<option value="lastmonth" <?php selected( 'lastmonth', $date_type ) ?>><?php _e( 'Last Month', 'handy-addons' ); ?></option>
	<option value="custom" <?php selected( 'custom', $date_type ) ?>><?php _e( 'Custom', 'handy-addons' ); ?></option>
</select>

<input class="datepicker of-date-input" type="text" name="from" value="<?php echo esc_html( $from ); ?>">
<input class="datepicker of-date-input" type="text" name="to" value="<?php echo esc_html( $to ) ?>">
<style>#filter-by-date{display: none;}</style>
<?php endif; ?>
