<?php
namespace Codexpert\Handy_Addons\Modules;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;
use Codexpert\Handy_Addons\Modules\PDF_Invoice\Admin;
use Codexpert\Handy_Addons\Modules\PDF_Invoice\Front;

/**
 * if accessed directly, exit.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * PDF Invoice
 *
 * Sends a PDF invoice with the order email
 *
 * @package Modules
 * @subpackage PDF_Invoice
 * @author codexpert <hi@codexpert.io>
 */
class PDF_Invoice extends Base {

	public $id;

	public $module;
	
	public static $_instance;

	/**
	 * Constructor function
	 */
	public function __construct() {

		$this->id = basename( __FILE__, '.php' );

		// if we have an addon activated for this module, don't proceed
		if( handy_addons_addon_is_active( $this->id ) ) return;

		// get the module data
		$this->module =  handy_addons_get_module( $this->id );

		$this->module['name'] = "{$this->module['icon']} {$this->module['name']}";

		// execute the hooks
		$this->hook();
	}

	public function hook() {
		// $this->activate( 'create_invoice_dir' );
		$this->action( 'admin_enqueue_scripts', 'enqueue_scripts' );
		$this->action( 'wp_enqueue_scripts', 'enqueue_scripts' );
		$this->action( 'plugins_loaded', 'add_menu', 11 );

		// if( is_admin() ) :
			include_once HANDY_ADDONS_DIR . "/modules/{$this->id}/src/Admin.php";
			$admin = new Admin();
		// else:
			include_once HANDY_ADDONS_DIR . "/modules/{$this->id}/src/Front.php";
			$front = new Front();
		// endif;
	}

	public function create_invoice_dir(){
		$upload_dir	= wp_upload_dir();
		$file_name	= ".htaccess";
		$dirpath	= $upload_dir['basedir'] . '/wcha-invoice/';
		$filepath	= $dirpath . $file_name;

		if( !file_exists( $dirpath ) ) {
			mkdir( $dirpath );	
		}

		if ( !file_exists( $filepath ) ) {
			file_put_contents( $filepath , 'deny from all' );
		}

		update_option( '_wcha_plugin_installed', time() );

	}

	public function enqueue_scripts() {
		wp_enqueue_style( $this->id, plugins_url( "modules/{$this->id}/assets/css/style.css", HANDY_ADDONS ) );
		wp_enqueue_script( $this->id, plugins_url( "modules/{$this->id}/assets/js/script.js", HANDY_ADDONS ), [ 'jquery' ], '0.1', true );
		$object = [
			'ajaxurl' => admin_url( 'admin-ajax.php' )
		];
		wp_localize_script( $this->id, 'WPS_INVOICE',$object );
	}

	public function add_menu() {
		// add_submenu_page( 'handy-addons', $this->module['name'], $this->module['name'], 'manage_options', $this->id, [ $this, 'callback_menu' ] );

		$date_format = get_option( 'date_format' );
		$settings = [
			'id'            => $this->id,
			'label'         => $this->module['name'],
			'title'         => __( 'PDF Invoice', 'handy-addons' ),
			'header'        => __( 'PDF Invoice', 'handy-addons' ),
			'priority'		=> 10,
			'capability'	=> 'manage_options',
			'parent'		=> 'handy-addons',
			'icon'			=> 'dashicons-yes',
			'position'		=> 56,
			'sections'      => [
				'pdf-general'	=> [
					'id'        => 'pdf-general',
					'label'     => __( 'General', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					// 'sticky'	=> true,
					'page_load'	=> false,
					'fields'    => [
						'enable-invoice' => [
							'id'        => 'enable-invoice',
							'label'     => __( 'Enable Invoice', 'handy-addons' ),
							'type'      => 'switch',
							'options'	=> [ 'yes', 'no' ],
							'desc'      => __( 'Enable invoice generation.', 'handy-addons' ),
						],
						'allow-invoicing-for' => [
							'id'        => 'allow-invoicing-for',
							'label'     => __( 'Allow Invoice for', 'handy-addons' ),
							'type'      => 'switch',
							'multiple'	=> true,
							'options'	=> function_exists( 'wc_get_order_statuses' ) ? wc_get_order_statuses() : [],
							'desc'      => __( 'Enable invoicing for order states', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],					
						'email-attachment' => [
							'id'        => 'email-attachment',
							'label'     => __( 'Send Invoice with email', 'handy-addons' ),
							'type'      => 'switch',
							'options'	=> [ 'yes', 'no' ],
							'desc'      => __( 'Send invoice with order email', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],
						'allow-email-invoicing-for' => [
							'id'        => 'allow-email-invoicing-for',
							'label'     => __( 'Allow email invoice for', 'handy-addons' ),
							'type'      => 'switch',
							'multiple'	=> true,
							'options'	=> function_exists( 'wc_get_order_statuses' ) ? wc_get_order_statuses() : [],
							'desc'      => __( 'Enable email invoicing for order states', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'email-attachment',
								'compare' 	=> 'checked',
							]
						],
						'paper-size' => [
							'id'        => 'paper-size',
							'label'     => __( 'Paper Size', 'handy-addons' ),
							'type'      => 'select',
							'options'   => [ 
									'A3' 	=> __( 'A3', 'handy-addons' ),
									'A4' 	=> __( 'A4', 'handy-addons' ),
									'A5' 	=> __( 'A5', 'handy-addons' ),
								],
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],
						'date-formate' => [
							'id'        => 'date-formate',
							'label'     => __( 'Date Formate', 'handy-addons' ),
							'type'      => 'select',
							'options'   => [ 
								$date_format => date( $date_format ),
								'd F, Y' 	=> date('d F, Y'),
								'm/d/y'		=> date('m/d/y'),
								'd/m/y'		=> date('d/m/y'),
								'Y/m/d'		=> date('Y/m/d'),
								'm/d/Y'		=> date('m/d/Y'),
								'm-d-y'		=> date('m-d-y'),
								'd-m-y'		=> date('d-m-y'),
								'Y-m-d'		=> date('Y-m-d'),
								'm-d-Y'		=> date('m-d-Y'),
							],
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],
						'allow-download' => [
							'id'        => 'allow-download',
							'label'     => __( 'Allow downloading invoice', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Allow downloading invoice after placing', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],
						'download-btn-text' => [
							'id'        => 'download-btn-text',
							'label'     => __( 'Download Button Label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Get Invoice', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-invoice',
								'compare' 	=> 'checked',
							]
						],
					]
				],
				'pdf-content'	=> [
					'id'        => 'pdf-content',
					'label'     => __( 'Content', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					'sticky'	=> true,
					'page_load'	=> true,
					'fields'    => [
						'enabled-heading' => [
							'id'        => 'enabled-heading',
							'label'     => __( 'Enable Heading', 'handy-addons' ),
							'type'      => 'switch',
							'desc'      => __( 'Enable heading to invoice', 'handy-addons' ),
						],
						'company-logo' => [
							'id'        => 'company-logo',
							'label'     => __( 'Company Logo', 'handy-addons' ),
							'type'      => 'file',
							'condition' => [
								'key' 		=> 'enabled-heading',
								'compare' 	=> 'checked',
							]
						],
						'company-address' => [
							'id'        => 'company-address',
							'label'     => __( 'Company Address', 'handy-addons' ),
							'type'      => 'textarea',
							'condition' => [
								'key' 		=> 'enabled-heading',
								'compare' 	=> 'checked',
							]
						],
						'company-email' => [
							'id'        => 'company-email',
							'label'     => __( 'Company Email', 'handy-addons' ),
							'type'      => 'email',
							'condition' => [
								'key' 		=> 'enabled-heading',
								'compare' 	=> 'checked',
							]
						],
						'company-phone' => [
							'id'        => 'company-phone',
							'label'     => __( 'Company Phone', 'handy-addons' ),
							'type'      => 'text',
							'condition' => [
								'key' 		=> 'enabled-heading',
								'compare' 	=> 'checked',
							]
						],
						'show-billing' => [
							'id'        => 'show-billing',
							'label'     => __( 'Show Billing Address', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Show billing address to invoice', 'handy-addons' ),
						],
						'show-shipping' => [
							'id'        => 'show-shipping',
							'label'     => __( 'Show Shipping Address', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Show shipping address to invoice', 'handy-addons' ),
						],
						'show-order-info' => [
							'id'        => 'show-order-info',
							'label'     => __( 'Show order info', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Show order info to invoice', 'handy-addons' ),
						],
						'product-table-cols' => [
							'id'        => 'product-table-cols',
							'label'     => __( 'Product table columns', 'handy-addons' ),
							'type'      => 'switch',
							'multiple'  => true,
							'options'  	=> [
								'image' 	=> __( 'Image', 'handy-addons' ),
								'name' 		=> __( 'Name', 'handy-addons' ),
								'price' 	=> __( 'Price', 'handy-addons' ),
								'quantity' 	=> __( 'Quantity', 'handy-addons' ),
								'total' 	=> __( 'Total', 'handy-addons' ),
							],
							'default'      => [ 'image', 'name', 'price', 'quantity', 'total' ],
						],
						'show-order-note' => [
							'id'        => 'show-order-note',
							'label'     => __( 'Show order note', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Show order note to invoice', 'handy-addons' ),
						],
						'show-seal' => [
							'id'        => 'show-seal',
							'label'     => __( 'Show Seal', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'on',
							'desc'      => __( 'Attached to invoice', 'handy-addons' ),
						],
						'seal' => [
							'id'        => 'seal',
							'label'     => __( 'Seal', 'handy-addons' ),
							'type'      => 'file',
							'condition' => [
								'key' 		=> 'show-seal',
								'compare' 	=> 'checked',
							]
						],
						'enable-footer' => [
							'id'        => 'enable-footer',
							'label'     => __( 'Enable Footer', 'handy-addons' ),
							'type'      => 'switch',
							'desc'      => __( 'Add a footer to invoice', 'handy-addons' ),
						],
						'signature' 	=> [
							'id'        => 'signature',
							'label'     => __( 'signature', 'handy-addons' ),
							'type'      => 'file',
							'condition' => [
								'key' 		=> 'enable-footer',
								'compare' 	=> 'checked',
							]
						],
						'footer-note' => [
							'id'        => 'footer-note',
							'label'     => __( 'Footer Note', 'handy-addons' ),
							'type'      => 'textarea',
							'condition' => [
								'key' 		=> 'enable-footer',
								'compare' 	=> 'checked',
							]
						],
					]
				],
				'pdf-templates'	=> [
					'id'        => 'pdf-templates',
					'label'     => __( 'Templates', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					'sticky'	=> true,
					'page_load'	=> false,
					'hide_form'	=> true,
					'content'	=> Helper::get_template( 'templates', "modules/{$this->id}/views/dashboard" ),
					// 'fields'    => [
					// 	'templates' => [
					// 		'id'        => 'templates',
					// 		'label'     => __( '', 'handy-addons' ),
					// 		'type'      => 'select',
					// 		'options'   => [
					// 			'template-1' => __( 'Template-1', 'handy-addons' ),
					// 			'template-2' => __( 'Template-2', 'handy-addons' ),
					// 			'template-3' => __( 'Template-3', 'handy-addons' ),
					// 			'template-4' => __( 'Template-4', 'handy-addons' ),
					// 		],
					// 	],
					// ]
				],
			],
		];

		new \Codexpert\Plugin\Settings( $settings );
	}

	public function callback_menu() {
		echo "
		<div class='wrap'>
			<h2>". esc_html( $this->module['name'] ) ."</h2>
		</div>";
		echo Helper::get_template( 'dashboard', "modules/{$this->id}/views/dashboard", [ 'module' => $this->module ] );
	}

	/**
	 * Instantiate the module
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
}
PDF_Invoice::instance();