<?php 
namespace codexpert\Handy_Addons\Modules\PDF_Invoice;
use Mpdf\Mpdf;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;

/**
 * All front classes
 * 
 * @author Jakaria Istauk <jakariamd35@gmail.com>
 */
class Front extends Base
{
	
	public function __construct() {
		$this->id = 'pdf-invoice';
		$this->hooks();
	}

	public function hooks() {
		$this->action( 'woocommerce_order_details_after_order_table', 'generate_pdf' );
		$this->filter( 'woocommerce_email_attachments', 'attach_invoice_to_order_email', 10, 3 );
		$this->filter( 'woocommerce_my_account_my_orders_columns', 'add_pdf_invoice_column' );
		$this->action( 'woocommerce_my_account_my_orders_column_order-invoice', 'add_pdf_invoice_btn_to_table' );
		$this->action( 'wp_loaded', 'download_invoice' );
	}

	/**
	 * Generate pdf invoice
	 * @param $order_id int
	 * 
	 * @return file_path | url pdf invoice path | url
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com>
	 * 
	 * @since 1.0
	 * 
	 */
	public function generate_pdf_invoice( $order_id, $type = 'path' ) {

		$upload_dir	= wp_upload_dir();
		$file_name	= "invoice_{$order_id}.pdf";
		$dirpath	= $upload_dir['basedir'] . '/wcha-invoice/';
		$filepath	= $dirpath . $file_name;

		if( !file_exists( $dirpath ) ) {
			mkdir( $dirpath );	
		}

		if ( !file_exists( $filepath ) ) {
			file_put_contents( $filepath , 'deny from all' );
		}

		$settings 		= get_option( 'pdf-general' );
		$template 		= get_option( 'wcha-pdf-invoice-template' );

		$html_content 	= Helper::get_template( $template, "modules/{$this->id}/views/invoice-templates", [ 'order_id' => $order_id ] );

		$stylesheet_url = HANDY_ADDONS_DIR . "/modules/{$this->id}/assets/css/{$template}.css";
		$defaultCss_url = HANDY_ADDONS_DIR . "/modules/{$this->id}/assets/css/default.css";

		$mpdf 			= new Mpdf( [ 'mode' => 'utf-8', 'format' => $settings['paper-size'] ] );
		$stylesheet 	= file_get_contents( $defaultCss_url );
		$stylesheet    .= file_get_contents( $stylesheet_url );

		$mpdf->SetDefaultBodyCSS( 'font-family', 'sans-serif' ); 
		 
		$mpdf->WriteHTML( $stylesheet, 1 );
		$mpdf->WriteHTML( $html_content );
		$content = $mpdf->Output( '', 'S' );

		file_put_contents( $filepath , $content );

		if ( $type == 'url' ) {
			return $upload_dir['baseurl'] . '/wcha-invoice/' . $file_name;
		}

		return $filepath;
	}

	public function generate_pdf( $order ) {

		$statuses 			= wc_get_order_statuses();
		$general_settings 	= get_option( 'pdf-general' );

		if ( !isset( $general_settings['enable-invoice'] ) || empty( $general_settings['allow-invoicing-for'] ) ) return;

		if( !in_array( 'wc-' . $order->get_status(), $general_settings['allow-invoicing-for'] ) ) return;

		if ( isset( $general_settings['allow-download'] ) ) {
			$order_id 			= $order->get_id();
			$current_url 		= home_url( sanitize_url( $_SERVER['REQUEST_URI'] ) );
			$request_url 		= add_query_arg( 'invoice-id', $order->get_id(), $current_url );
			$content_settings 	= get_option( 'pdf-content' );

			if ( ! $content_settings || count( $content_settings ) < 1 ) return;

			echo "<a class='button wps-invoice-download-btn' href='{$request_url}'>{$general_settings['download-btn-text']}</a>";
		}
	}

	public function attach_invoice_to_order_email( $attachments , $email_id, $order ) {

	    if ( !$order instanceof \WC_Order ) {
	        return $attachments;
	    }

	    $general_settings = get_option( 'pdf-general' );
	    if( 
	    	isset( $general_settings['allow-email-invoicing-for'] ) && 
	    	!empty( $general_settings['allow-email-invoicing-for'] ) && 
	    	!in_array( 'wc-' . $order->get_status(), $general_settings['allow-email-invoicing-for'] ) 
	    ) {
	    	return $attachments;
	    }

		$attachments[] = $this->generate_pdf_invoice( $order->get_id() );
		return $attachments;
	}

	public function add_pdf_invoice_column( $columns )	{
		$new_columns = array();

	    foreach ( $columns as $key => $name ) {

	        $new_columns[ $key ] = $name;

	        // add ship-to after order status column
	        if ( 'order-actions' === $key ) {
	            $new_columns['order-invoice'] = __( 'Invoice', 'handy-addons' );
	        }
	    }

	    return $new_columns;
	}

	public function add_pdf_invoice_btn_to_table( $order ){
		$settings = get_option( 'pdf-general' );
		if( !in_array( 'wc-' . $order->get_status(), $settings['allow-invoicing-for'] ) ) return;

		$current_url 		= home_url( sanitize_text_field( $_SERVER['REQUEST_URI'] ) );
		$request_url 		= add_query_arg( 'invoice-id', $order->get_id(), $current_url );
		$content_settings 	= get_option( 'pdf-content' );

		if ( !$content_settings || count( $content_settings ) < 1 ) return;

		echo "<a class='button wps-invoice-download-btn' href='{$request_url}'>{$settings['download-btn-text']}</a>";
	}

	public function download_invoice() {

		if ( !isset( $_GET['invoice-id'] ) ) return;

		if ( !is_user_logged_in() ) return;

		$order_id 		= sanitize_text_field( $_GET['invoice-id'] );
		$invoice_url 	= $this->generate_pdf_invoice( $order_id );
		
		if (file_exists($invoice_url)) {
		  ob_start();
		  header("Content-Type: application/pdf");
		  header("Content-Disposition: attachment; filename=Invoice_".$order_id);
		  header("Content-Length: ".filesize($invoice_url));
		  header("Content-Transfer-Encoding: binary");
		  readfile($invoice_url);
		  ob_end_flush();
		  die(); // To not send the HTML afterwards
		} 
		else die("Not found");
	}
}