<?php 
use Codexpert\Handy_Addons\Helper;
global $woocommerce;

$order_id 			= $args['order_id'];
$order 				= wc_get_order( $order_id );
$content_settings 	= get_option( 'pdf-content' );
$general_settings 	= get_option( 'pdf-general' );
$format 			= get_option( 'date_format' ) . ' ' . get_option( 'time_format' );
$order_date 		= date( $format, strtotime( $order->get_date_created() ) );

$table_rows			= '';
$invoice_number		= '#5454654';
$company_logo  		= $content_settings['company-logo'] ? "<img src='" . esc_url( $content_settings['company-logo'] ) . "' width='150'>" : '';
$invoice_seal  		= isset( $content_settings['seal']  ) ? "<img src='" . esc_url( $content_settings['seal'] ) . "' width='100'>" : '';
$owner_signature  	= $content_settings['signature'] ? "<img src='" . esc_url( $content_settings['signature'] ) . "' width='100'>" : '';
$currency 			= get_woocommerce_currency_symbol();

foreach ( $order->get_items() as $key => $item ) {
	$product = $item->get_product();

	if( $product->is_type('variation') ){
	   $variation_attributes = $product->get_variation_attributes();
	}

	$image_id  	= $product->get_image_id();
	$image_url 	= wp_get_attachment_image_url( $image_id, 'full' );

	$_table_row = "";
	if ( in_array( 'image', $content_settings['product-table-cols'] ) ) {
		$_table_row .= "<td class='invoice-data align-left'><img src='{$image_url}' width='50'></td>";
	}
	if ( in_array( 'name', $content_settings['product-table-cols'] ) ) {
		$_table_row .= "<td class='invoice-data align-left'>{$item->get_name()}</td>";
	}
	if ( in_array( 'price', $content_settings['product-table-cols'] ) ) {
		$_table_row .= "<td class='invoice-data'>{$currency}{$product->get_price()}</td>";
	}
	if ( in_array( 'quantity', $content_settings['product-table-cols'] ) ) {
		$_table_row .= "<td class='invoice-data'>{$item->get_quantity()}</td>";
	}
	if ( in_array( 'total', $content_settings['product-table-cols'] ) ) {
		$_table_row .= "<td class='invoice-data'>{$currency}{$item->get_total()}</td>";
	}

	$table_rows .= "<tr>{$_table_row}</tr>";
}
?>
<div class="wcha-pdf-invoice-container">
	<?php if ( isset( $content_settings['enabled-heading'] ) && $content_settings['enabled-heading'] == 'on' ): ?>
	<table class="wcha-invoice-header">
		<tbody>
			<tr>
				<td class="wcha-invoice-logo">
					<?php echo wp_kses_post( $company_logo ); ?>
				</td>
				<td class="invoice-data">
					<?php 
					echo "<span class='wcha-table-column-row'>" . esc_textarea( $content_settings['company-address'] ) . "</span><br>";
					?>
				</td>
			</tr>
		</tbody>
	</table>
	<br><br>
	<?php endif; ?>

	<table class="wcha-invoice-customer-info">
		<tbody>
			<tr>
				<td class="invoice-data">
					<?php if ( isset( $content_settings['show-billing'] ) && $content_settings['show-billing'] == 'on' ): ?>
						<h6 class="pdf-invoice-title"><?php _e( 'Billing Address', 'handy-addons' ) ?></h6>
						<p class="billing-address"><?php echo wp_kses_post( $order->get_formatted_billing_address() ); ?></p>
						<p><?php echo __( 'Phone: ', 'handy-addons' ) . esc_html( $order->get_billing_phone() ); ?></p>
						<p><?php echo __( 'Email: ', 'handy-addons' ) . esc_html( $order->get_billing_email() ); ?></p>
					<?php endif; ?>
				</td>

				<td class="invoice-data">
					<?php if ( isset( $content_settings['show-shipping'] ) && $content_settings['show-shipping'] == 'on' && $order->get_formatted_shipping_address() ): ?>
						<h6 class="pdf-invoice-title"><?php _e( 'Shipping Address', 'handy-addons' ) ?></h6>
						<p><?php echo wp_kses_post( $order->get_formatted_shipping_address() ); ?></p>
					<?php endif; ?>
				</td>

				<td>
					<?php if ( isset( $content_settings['show-order-info'] ) && $content_settings['show-order-info'] == 'on' ): ?>
						<table class="wcha-invoice-order-info">
							<tbody>
								<tr>
									<td colspan="2">
										<h6 class="pdf-invoice-title"><?php echo __( 'Invoice Number ', 'handy-addons' ). esc_html( $invoice_number ); ?></h6>
									</td>
								</tr>
								<tr>
									<td class="invoice-data"><?php _e( 'Payment Method', 'handy-addons' ) ?></td>
									<td class="invoice-data"><?php echo ' : ' . esc_html( $order->get_payment_method_title() );  ?></td>
								</tr>
								<tr>
									<td class="invoice-data"><?php _e( 'Order Number', 'handy-addons' ) ?></td>
									<td class="invoice-data"><?php echo ' : ' . esc_html( $order->get_id() );  ?></td>
								</tr>
								<tr>
									<td class="invoice-data"><?php _e( 'Order Date', 'handy-addons' ) ?></td>
									<td class="invoice-data"><?php echo ' : ' . esc_html( date( 'M d, Y', strtotime( $order->get_date_created() ) ) );  ?></td>
								</tr>
							</tbody>
						</table>
					<?php endif; ?>
				</td>
			</tr>
		</tbody>
	</table>
	<br><br>

	<table class="wcha-invoice-products">
		<thead>
			<tr>
				<?php if ( in_array( 'image', $content_settings['product-table-cols'] ) ): ?>
					<th class="align-left"><?php _e( 'Image', 'handy-addons' ) ?></th>
				<?php endif;

				if ( in_array( 'name', $content_settings['product-table-cols'] ) ): ?>
					<th class="align-left"><?php _e( 'Product', 'handy-addons' ) ?></th>
				<?php endif;

				if ( in_array( 'price', $content_settings['product-table-cols'] ) ): ?>
					<th><?php _e( 'Price', 'handy-addons' ) ?></th>
				<?php endif;

				if ( in_array( 'quantity', $content_settings['product-table-cols'] ) ): ?>
					<th><?php _e( 'Quantity', 'handy-addons' ) ?></th>
				<?php endif;

				if ( in_array( 'total', $content_settings['product-table-cols'] ) ): ?>
					<th><?php _e( 'Total', 'handy-addons' ) ?></th>
				<?php endif; ?>
			</tr>
		</thead>
		<tbody>
			<?php echo wp_kses_post( $table_rows ); ?>
		</tbody>
	</table>
	<br>

	<table class="wcha-invoice-total-pricing">
		<tbody>
			<tr>
				<td class="wcha-invoice-seal">
					<?php echo wp_kses_post( $invoice_seal ); ?>
				</td>
				<td class="wcha-invoice-order-totals">
					<table class="wcha-invoice-order-totals-table">
						<tbody>
							<tr>
								<td class="invoice-data"><?php _e( 'Item Subtotal', 'handy-addons' ) ?></td>
								<td class="invoice-data"><?php echo esc_html( $order->get_subtotal() ); ?></td>
							</tr>
							<tr>
								<td class="invoice-data"><?php _e( 'Shipping', 'handy-addons' ) ?></td>
								<td class="invoice-data"><?php echo esc_html( $order->get_shipping_total() ); ?></td>
							</tr>
							<tr>
								<td class="invoice-data"><?php _e( 'Order Total', 'handy-addons' ) ?></td>
								<td class="invoice-data"><?php echo esc_html( $order->get_total() ); ?></td>
							</tr>
						</tbody>
					</table>
				</td>
			</tr>
		</tbody>
	</table>
	<br>
	<br>
	<br>

	<?php if ( isset( $content_settings['show-order-note'] ) && $content_settings['show-order-note'] == 'on' && $order->get_customer_note() ): ?>
	<div class="wcha-invoice-customer-notes">
		<div class="invoice-data"><?php _e( 'Customer note: ', 'handy-addons' ); echo esc_html( $order->get_customer_note() ); ?></div >
	</div>
	<br>
	<br>
	<br>

	<?php endif;

	if ( isset( $content_settings['enable-footer'] ) && $content_settings['enable-footer'] == 'on' ): ?>
		<table class="wcha-invoice-footer">
			<tbody>
				<tr>
					<td class="invoice-data shop-owner-note"><?php echo stripslashes( esc_html( $content_settings['footer-note'] ) ); ?></td>
					<td class="invoice-data shop-owner-signature">
						<?php echo wp_kses_post( $owner_signature ); ?>
					</td>
				</tr>
			</tbody>
		</table>
	<?php endif; ?>
</div>