<?php
namespace Codexpert\Handy_Addons\Modules;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;
use Codexpert\Handy_Addons\Modules\Product_Brands\Admin;
use Codexpert\Handy_Addons\Modules\Product_Brands\Front;

/**
 * if accessed directly, exit.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * PDF Invoice
 *
 * Sends a PDF invoice with the order email
 *
 * @package Modules
 * @subpackage Product_Brands
 * @author codexpert <hi@codexpert.io>
 */
class Product_Brands extends Base {

	public $id;

	public $module;
	
	public static $_instance;

	/**
	 * Constructor function
	 */
	public function __construct() {

		$this->id = basename( __FILE__, '.php' );

		// if we have an addon activated for this module, don't proceed
		if( handy_addons_addon_is_active( $this->id ) ) return;

		// get the module data
		$this->module =  handy_addons_get_module( $this->id );

		$this->module['name'] = "{$this->module['icon']} {$this->module['name']}";

		// execute the hooks
		$this->hook();
	}

	public function hook() {
		$this->action( 'admin_enqueue_scripts', 'enqueue_scripts' );
		$this->action( 'wp_enqueue_scripts', 'enqueue_scripts' );
		$this->action( 'plugins_loaded', 'add_menu', 11 );

		// if( is_admin() ) :
			include_once HANDY_ADDONS_DIR . "/modules/{$this->id}/src/Admin.php";
			$admin = new Admin();
		// else:
			include_once HANDY_ADDONS_DIR . "/modules/{$this->id}/src/Front.php";
			$front = new Front();
		// endif;
	}

	public function enqueue_scripts() {
		wp_enqueue_style( $this->id, plugins_url( "modules/{$this->id}/assets/css/style.css", HANDY_ADDONS ) );
		wp_enqueue_script( $this->id, plugins_url( "modules/{$this->id}/assets/js/script.js", HANDY_ADDONS ), [ 'jquery' ], '0.1', true );

        wp_enqueue_media();
		$object = [
			'ajaxurl' 		=> admin_url( 'admin-ajax.php' ),
			'title' 		=> __( 'Upload an Image', 'handy-addons' ),
            'media_button' 	=> __( 'Use this Image', 'handy-addons' ),
            'rmv_btn_text' 	=> __( 'Remove Image', 'handy-addons' ),
            'wc_placeholder_img_src' => wc_placeholder_img_src(),
		];
		wp_localize_script( $this->id, 'PRODUCT_BRANDS',$object );
	}

	/**
	 * Add Settings page to product brand module
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_menu() {
		
		$settings = [
			'id'            => $this->id,
			'label'         => $this->module['name'],
			'title'         => __( 'Product Brands', 'handy-addons' ),
			'header'        => __( 'Product Brands', 'handy-addons' ),
			'priority'		=> 10,
			'capability'	=> 'manage_options',
			'parent'		=> 'handy-addons',
			'icon'			=> 'dashicons-yes',
			'position'		=> 56,
			'sections'      => [
				'pb-general'	=> [
					'id'        => 'pb-general',
					'label'     => __( 'General', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					// 'sticky'	=> true,
					'page_load'	=> true,
					'fields'    => [
						'enable-brands' => [
							'id'        => 'enable-brands',
							'label'     => __( 'Enable Product Brands', 'handy-addons' ),
							'type'      => 'switch',
						],
						'slug' => [
							'id'        => 'slug',
							'label'     => __( 'Brands Taxonomy Slug', 'handy-addons' ),
							'type'      => 'text',
							'default'   => 'product_brands',
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'show_admin_column' => [
							'id'        => 'show_admin_column',
							'label'     => __( 'Show Brands on product table', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'off',
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'show_in_rest' => [
							'id'        => 'show_in_rest',
							'label'     => __( 'Allow rest API', 'handy-addons' ),
							'type'      => 'switch',
							'default'   => 'off',
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'name' => [
							'id'        => 'name',
							'label'     => __( 'Brands Name', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Brands', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'singular_name' => [
							'id'        => 'singular_name',
							'label'     => __( 'Brands singular name', 'handy-addons' ),
							'type'      => 'text',
							'default'      => __( 'Brand', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'search_items' => [
							'id'        => 'search_items',
							'label'     => __( 'Search items label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Search Brands' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'all_items' => [
							'id'        => 'all_items',
							'label'     => __( 'All items label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'All Brands' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'parent_item' => [
							'id'        => 'parent_item',
							'label'     => __( 'Parent item label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Parent Brand', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'parent_item_colon' => [
							'id'        => 'parent_item_colon',
							'label'     => __( 'Parent item colon label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Parent Brand:', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'edit_item' => [
							'id'        => 'edit_item',
							'label'     => __( 'Edit Brand label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Edit Brand', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'update_item' => [
							'id'        => 'update_item',
							'label'     => __( 'Update Brand label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Update Brand', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'add_new_item' => [
							'id'        => 'add_new_item',
							'label'     => __( 'Add New Brand label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Add New Brand', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'new_item_name' => [
							'id'        => 'new_item_name',
							'label'     => __( 'New Brand Name label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'New Brand Name', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
						'menu_name' => [
							'id'        => 'menu_name',
							'label'     => __( 'Menu label', 'handy-addons' ),
							'type'      => 'text',
							'default'   => __( 'Brands', 'handy-addons' ),
							'condition' => [
								'key' 		=> 'enable-brands',
								'compare' 	=> 'checked',
							]
						],
					]
				],
			],
		];

		$brand_enabled = Helper::get_option( 'pb-general', 'enable-brands' );
		if ( $brand_enabled ){
			$settings['sections']['pb-display'] = [
					'id'        => 'pb-display',
					'label'     => __( 'Display', 'handy-addons' ),
					'icon'      => 'dashicons-screenoptions',
					'color'		=> '#4c3f93',
					// 'sticky'	=> true,
					'page_load'	=> true,
					'fields'    => [
						'display-on-product-page' => [
							'id'        => 'display-on-product-page',
							'label'     => __( 'Display on product page', 'handy-addons' ),
							'type'      => 'switch',
						],
						'enable-archive' => [
							'id'        => 'enable-archive',
							'label'     => __( 'Enable Archive Page', 'handy-addons' ),
							'type'      => 'switch',
						],
					],
				];
		}

		new \Codexpert\Plugin\Settings( $settings );
	}

	public function callback_menu() {
		echo "
		<div class='wrap'>
			<h2>". esc_html( $this->module['name'] ) ."</h2>
		</div>";
		echo Helper::get_template( 'dashboard', "modules/{$this->id}/views/dashboard", [ 'module' => $this->module ] );
	}

	/**
	 * Instantiate the module
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
}

Product_Brands::instance();