<?php 
namespace codexpert\Handy_Addons\Modules\Product_Brands;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;

/**
 * All admin classes
 * 
 * @author Jakaria Istauk <jakariamd35@gmail.com>
 */
class Admin extends Base {
	
	public function __construct(){
		$this->hooks();
	}

	public function hooks(){
		$this->action( 'admin_head', 'head' );

		$settings = get_option( 'pb-general' );
		
		if ( isset( $settings['enable-brands'] ) ){
			$brand_slug = $settings['slug'];
			$this->action( 'init', 'register_brand_taxonomy' );
			$this->action( 'presenters_edit_form_fields', 'presenters_taxonomy_custom_fields', 10, 2 );
			$this->action( "{$brand_slug}_add_form_fields", 'add_term_image', 10, 2 );
			$this->action( "created_{$brand_slug}", 'save_term_image', 10, 2);
			$this->action( "{$brand_slug}_edit_form_fields", 'edit_image_upload', 12, 2 );
			$this->action( "edited_{$brand_slug}", 'update_image_upload', 10, 2);
			$this->filter( "manage_{$brand_slug}_custom_column", 'add_img_column',10,3 );
			$this->filter( "manage_edit-{$brand_slug}_columns", 'add_logo_column');
			$this->filter( 'manage_edit-product_columns', 'add_brand_column' );
			$this->action( 'manage_posts_custom_column', 'add_brand_columns_content' );
		}
	}

	public function head(){}

	/**
	 * Register Custom Taxonomy
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function register_brand_taxonomy() {

		$settings 	= get_option( 'pb-general' );
		$is_archive = Helper::get_option( 'pb-display', 'enable-archive' );
		 
		  $labels 	= array(
		    'name' 				=> $settings['name'],
		    'singular_name' 	=> $settings['singular_name'],
		    'search_items' 		=> $settings['search_items'],
		    'all_items' 		=> $settings['all_items'],
		    'parent_item' 		=> $settings['parent_item'],
		    'parent_item_colon' => $settings['parent_item_colon'],
		    'edit_item' 		=> $settings['edit_item'], 
		    'update_item' 		=> $settings['update_item'],
		    'add_new_item' 		=> $settings['add_new_item'],
		    'new_item_name' 	=> $settings['new_item_name'],
		    'menu_name' 		=> $settings['menu_name'],
		  );    
		 
		// Now register the taxonomy
		  register_taxonomy( $settings['slug'], array('product'), array(
		    'hierarchical' 	=> true,
		    'labels' 		=> $labels,
		    'show_ui' 		=> true,
		    'show_in_rest' 	=> isset( $settings['show_in_rest'] ) && $settings['show_in_rest'] == 'on' ? true : false,
		    'query_var' 	=> true,
		    'public' 		=> $is_archive ? true : false,
		    'rewrite' 		=> array( 'slug' => $settings['slug'] ),
		  ));	 
	}

	/**
	 * Add custom form field on taxonomy admin page
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_term_image( $taxonomy ){
		$wc_place_holder_img = wc_placeholder_img_src();
	    ?>

	    <div class="form-field term-group pb-brand-form term-thumbnail-wrap">
	        <h4><?php _e( 'Thumbnail', 'handy-addons' ) ?></h4>
	        <input type="hidden" name="product_brand_logo" id="product_brand_logo" value="">
	        <img id="product-brand-logo-preview" src=" <?php echo esc_url( $wc_place_holder_img ); ?>" height='60' width='60'>	       
	        <input type="button" id="upload_brand_logo_btn" class="button" value="<?php _e( 'Upload/Add image', 'handy-addons' ); ?>" />
	    </div>

	    <?php
	}

	/**
	 * save taxonomy custom data
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function save_term_image( $term_id, $tt_id ) {
	    if ( isset( $_POST['product_brand_logo'] ) && '' !== $_POST['product_brand_logo'] ) {
	        $img_url = sanitize_url( $_POST['product_brand_logo'] );
	        add_term_meta( $term_id, 'product_brand_logo', $img_url );
	    }
	}

	/**
	 * Add custom form field on taxonomy edit screen
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function edit_image_upload( $term, $taxonomy ) {
	    // get current img_url
	    $product_brand_logo = get_term_meta( $term->term_id, 'product_brand_logo', true );
	    $show_image 		= '';
	    $btn_text 			= __( 'Upload/Add image', 'handy-addons' );
	    $title 				= __( 'Thumbnail', 'handy-addons' );

	    if ( !$product_brand_logo ) {	    	
			$product_brand_logo = wc_placeholder_img_src();
	    }

		echo "
			<tr>
				<td><label for='product_brand_logo'>". esc_html( $title ) ."</label></td>
				<td>
					<div>
				        <input type='hidden' name='product_brand_logo' id='product_brand_logo' value=". esc_attr( $product_brand_logo ) .">
				        <img id='product-brand-logo-preview' src=". esc_url( $product_brand_logo ) ." height='60' width='60' >
				        <input type='button' id='upload_brand_logo_btn' class='button' value=". esc_attr( $btn_text ) ." />
					</div>
				</td>
			</tr>
		";
	}

	/**
	 * update taxonomy custom data
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function update_image_upload( $term_id, $tt_id ) {
	    if ( isset($_POST['product_brand_logo']) ){
	        $img_url = sanitize_url( $_POST['product_brand_logo'] );
	        update_term_meta( $term_id, 'product_brand_logo', $img_url );
	    }
	}

	/**
	 * Add logo column in taxonomy list table
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_logo_column( $columns ) {
	    
	    $name 			= isset( $columns['name'] ) ? $columns['name'] : '';
	    $description 	= isset( $columns['description'] ) ? $columns['description'] : '';
	    $slug 			= isset( $columns['slug'] ) ? $columns['slug'] : '';
	    $posts 			= isset( $columns['posts'] ) ? $columns['posts'] : '';

	    unset( $columns['name'] );
		unset( $columns['description'] );
		unset( $columns['slug'] );
		unset( $columns['posts'] );

		$columns['logo'] 		= __( 'Logo', 'handy-addons' );
		$columns['name'] 		= $name;
		$columns['description'] = $description;
		$columns['slug'] 		= $slug;
		$columns['posts'] 		= $posts;

	    return $columns;
	}

	/**
	 * Add logo column's content in taxonomy list table
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_img_column( $content, $column_name, $term_id ){
	    $logo_url = get_term_meta( $term_id, 'product_brand_logo', true );

	    if ( $column_name == 'logo' ) {
	    	if ( !$logo_url ) {
	    		$logo_url = wc_placeholder_img_src();
	    	}
	    	return "<img src=". esc_url( $logo_url ) ." width='48' height='48' >";
	    }
	}

	/**
	 * Add brand column in product list table
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_brand_column( $columns ){

		$settings = get_option( 'pb-general' );

		$date 		= $columns['date'];
		$featured 	= $columns['featured'];

		unset( $columns['date'] );
		unset( $columns['featured'] );

		$columns['product_brand'] 	= $settings['name'];
		$columns['date'] 			= $date;
		$columns['featured'] 		= $featured;

		return $columns;
	}

	/**
	 * Add brand column's content in product list table
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function add_brand_columns_content( $column_name ) {

		$settings = get_option( 'pb-general' );

		global $post;

		if( $column_name == 'product_brand' ) { 
			$brands = get_the_terms( $post, $settings['slug'] );

			if ( $brands ) {
				$brand_names = [];
				foreach ( $brands as $brand ) {
					$brand_names[] = $brand->name;
				}
				echo wp_kses_post( implode( ', ', $brand_names ) );
			}
		}
	}
}