<?php 
namespace codexpert\Handy_Addons\Modules\Product_Brands;
use Mpdf\Mpdf;
use Codexpert\Plugin\Base;
use Codexpert\Handy_Addons\Helper;

/**
 * All front classes
 * 
 * @author Jakaria Istauk <jakariamd35@gmail.com>
 */
class Front extends Base {
	
	function __construct(){
		$this->id = 'pdf-invoice';
		$this->hooks();
	}

	public function hooks() {
		$this->action( 'wp_head', 'head' );
		$settings = get_option( 'pb-general' );

		if ( isset( $settings['enable-brands'] ) ){
			$this->action( 'woocommerce_product_meta_end', 'show_brand_on_single_page' );
			$this->action( 'woocommerce_after_shop_loop_item', 'show_brand_in_shop' );
		}
	}

	public function head() {}

	/**
	 * Show product brands on product single page
	 * 
	 * @since 1.0
	 * 
	 * @author Jakaria Istauk <jakariamd35@gmail.com> 
	 */
	public function show_brand_on_single_page() {
		global $product;

		$settings 			= get_option( 'pb-general' );
		$display_enabled 	= Helper::get_option( 'pb-display', 'display-on-product-page' );

		if ( !$display_enabled ) return;

		$brands = get_the_terms( $product->get_id(), $settings['slug'] );

		if ( $brands ) {
			$is_archive 	= Helper::get_option( 'pb-display', 'enable-archive' );
			$brand_names 	= [];
			
			foreach ( $brands as $brand ) {
				if ( $is_archive ) {
					$term_url = get_term_link( $brand );
					$brand_names[] =  "<a href='{$term_url}'>{$brand->name}</a>";
				}
				else {
					$brand_names[] = $brand->name;
				}
			}
			echo "<span class='brand_wrapper'>" . wp_kses_post( $settings['singular_name'] . ': ' . implode( ', ', $brand_names ) ) . "</span>";
		}
	}

	/**
	 * Show product brands on product shop page
	 * 
	 * @since 1.0
	 * 
	 * @author Al Imran Akash <alimranakash.bd@gmail.com> 
	 */
	public function show_brand_in_shop() {
		global $product;

		$settings 			= get_option( 'pb-general' );
		$display_enabled 	= Helper::get_option( 'pb-display', 'enable-archive' );

		if ( !$display_enabled ) return;

		$brands = get_the_terms( $product->get_id(), $settings['slug'] );

		if ( $brands ) {
			$is_archive 	= Helper::get_option( 'pb-display', 'enable-archive' );
			$brand_names 	= [];
			
			foreach ( $brands as $brand ) {
				if ( $is_archive ) {
					$term_url = get_term_link( $brand );
					$brand_names[] =  "<a class='woocommerce-loop-product__title' href='{$term_url}'>{$brand->name}</a>";
				}
				else {
					$brand_names[] = $brand->name;
				}
			}
			echo "<span class='brand_wrapper'>" . wp_kses_post( $settings['singular_name'] . ': ' . implode( ', ', $brand_names ) ) . "</span>";
		}
	}
}